package com.ibm.websphere.fabric.telco.incidentproblemmanagement.context.extractor;

import java.util.Iterator;
import java.util.Set;
import java.util.logging.Logger;

import com.ibm.websphere.fabric.da.PendingRequest;
import com.ibm.websphere.fabric.da.context.Context;
import com.ibm.websphere.fabric.da.plugin.ContextExtractor;
import com.ibm.websphere.fabric.da.plugin.UnexpectedContentException;
import com.ibm.websphere.fabric.da.types.TypedValue;
import com.ibm.websphere.fabric.da.util.SdoXPathUtil;
import com.ibm.websphere.fabric.da.util.XPathSearchResult;
import com.ibm.websphere.fabric.telco.util.IConstants;
import com.ibm.websphere.sca.ServiceManager;

import commonj.sdo.DataObject;

public class TroubleTypeExtractorImpl implements ContextExtractor {
	
	private final Logger logger = Logger.getLogger(this.getClass().getName()); 
	
	/**
	 * Default constructor.
	 */
	public TroubleTypeExtractorImpl() {
		super();
	}

	/**
	 * Return a reference to the component service instance for this implementation
	 * class.  This method should be used when passing this service to a partner reference
	 * or if you want to invoke this component service asynchronously.    
	 *
	 * @generated (com.ibm.wbit.java)
	 */
	@SuppressWarnings("unused")
	private ContextExtractor getMyService() {
		return (ContextExtractor) ServiceManager.INSTANCE.locateService("self");
	}

	/* (non-Javadoc)
	 * @see com.ibm.websphere.fabric.da.plugin.ContextExtractor#extractContext(PendingRequest arg0) 
	 */
	public Context extractContext(PendingRequest pendingRequest) throws UnexpectedContentException {
		
		Context context = pendingRequest.getContext();
		
		// Get the Request from Message Body
		DataObject requestDataObject = pendingRequest.getFirstBodyElement();
		//logger.info("TroubleTicketMessage Body: " + SdoUtil.printTree(requestDataObject));

		XPathSearchResult result = SdoXPathUtil.getViaXpath(requestDataObject, "//trouble_ticket");
		DataObject troubleTicket = (DataObject) result.getValue();

		String sTroubleType = "";
		if (troubleTicket != null) {
	       sTroubleType = troubleTicket.getString("Specification/Id");
		}
		
		// Special handling for Enrich/Verify Customer Problem  & Network Trouble
		//
		String sValue = (context.getSelectionProperty("http://www.webifysolutions.com/context/component")).getValue();
		if ((sValue.indexOf("EnrichTroubleDA")) > 0) { 
           sTroubleType = "Enrich_" + sTroubleType; 
		} 

		logger.info("Selected Trouble Type by User: " + sTroubleType);
		logger.info("This value will be set in " + IConstants.PROP_TROUBLE_TICKET_SPECIFICATION_ID + " property in Context. "); 

		context.setSelectionProperty(IConstants.PROP_TROUBLE_TICKET_SPECIFICATION_ID, new TypedValue(sTroubleType));
		context.setSelectionProperty(IConstants.FABRIC_GOVERNANCE_KEY, new TypedValue(IConstants.FABRIC_GOVERNANCE_VALUE)); 
	
		Set<String> selectionKeys = context.getSelectionPropertyNames();
		Iterator<String> iter = selectionKeys.iterator(); 
		while (iter.hasNext()) { 
		   String sKey = iter.next(); 
		   logger.info("Context Selection Key: " + sKey); 
		   logger.info("Context Selection Value: " + context.getSelectionProperty(sKey)); 
		}

		return context;
	}
}