/***********************************************
 * Licensed Materials - Property of IBM
 * 
 * 5724-R31, 5655-S30
 *
 * (C) Copyright IBM Corp. 2002, 2007 All Rights Reserved.
 * (C) Copyright Webify Solutions, Inc. 2002, 2007 All Rights Reserved.
 * 
 * US Government Users Restricted Rights - Use, duplication or
 * disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
 ***********************************************
 */
package com.ibm.websphere.fabric.telco.orderfeasibility.context.extractor;

import java.util.HashMap;
import java.util.Map;
import java.util.logging.Logger;

import com.ibm.websphere.fabric.da.PendingRequest;
import com.ibm.websphere.fabric.da.context.Context;
import com.ibm.websphere.fabric.da.plugin.ContextExtractor;
import com.ibm.websphere.fabric.da.plugin.UnexpectedContentException;
import com.ibm.websphere.fabric.da.util.SdoXPathUtil;
import com.ibm.websphere.fabric.da.util.XPathSearchResult;
import com.ibm.websphere.fabric.telco.util.BpelContextHandler;
import com.ibm.websphere.fabric.telco.util.IConstants;
import com.ibm.websphere.sca.ServiceManager;
import com.ibm.ws.fabric.da.sca.util.SdoUtil;
import commonj.sdo.DataObject;

/**
 * Retrives the state from the address and sets it into context properties map,
 * which is used by ServiceAvailability Assertion.
 * 
 * @author manoj.puthran
 */
public class AddressExtractorImpl implements ContextExtractor {

	private final Logger logger = Logger.getLogger(AddressExtractorImpl.class
			.getName());

	/**
	 * Default constructor.
	 */
	public AddressExtractorImpl() {
		super();
	}

	/**
	 * Return a reference to the component service instance for this
	 * implementation class. This method should be used when passing this
	 * service to a partner reference or if you want to invoke this component
	 * service asynchronously.
	 * 
	 * @generated (com.ibm.wbit.java)
	 */
	// CHECKSTYLE:OFF
	@SuppressWarnings("unused")
	private ContextExtractor getMyService() {
		return (ContextExtractor) ServiceManager.INSTANCE.locateService("self");
	}

	// CHECKSTYLE:ON

	/*
	 * (non-Javadoc)
	 * 
	 * @seecom.ibm.websphere.fabric.da.plugin.ContextExtractor#extractContext(
	 * PendingRequest arg0)
	 */
	public Context extractContext(PendingRequest pendingRequest)
			throws UnexpectedContentException {

		Context context = pendingRequest.getContext();

		// Get the Request from Message Body
		DataObject requestDataObject = pendingRequest.getFirstBodyElement();
		logger.info("endingRequest.getMessageBody()="
				+ SdoUtil.printTree(requestDataObject));

		XPathSearchResult result = SdoXPathUtil.getViaXpath(requestDataObject,
				"//urbanPropertyAddress");
		DataObject urbanPropertyAddress = (DataObject) result.getValue();

		String stateOrProvinceCd = "";
		if (urbanPropertyAddress != null) {
			stateOrProvinceCd = urbanPropertyAddress
					.getString("StateOrProvince");
		}
		logger.info("stateOrProvinceCd=" + stateOrProvinceCd);

		Map<Object, Object> contextMap = new HashMap<Object, Object>();
		contextMap.put(IConstants.STATE_ASSERT_VALUE, stateOrProvinceCd);
		contextMap.put(IConstants.FABRIC_GOVERNANCE_VALUE,
				IConstants.FABRIC_GOVERNANCE);

		BpelContextHandler.setContextProperties(contextMap);

		return context;
	}

}